==> s3lambda-1.95.1-sources.jar: software/amazon/awsconstructs/services/s3lambda/S3ToLambda.java <==
package software.amazon.awsconstructs.services.s3lambda;

@javax.annotation.Generated(value = "jsii-pacmak/1.26.0 (build 7d76e02)", date = "2021-04-02T21:59:20.953Z")
@software.amazon.jsii.Jsii(module = software.amazon.awsconstructs.services.s3lambda.$Module.class, fqn = "@aws-solutions-constructs/aws-s3-lambda.S3ToLambda")
public class S3ToLambda extends software.amazon.awscdk.core.Construct {

    protected S3ToLambda(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected S3ToLambda(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope - represents the scope for all the resources. This parameter is required.
     * @param id - this is a a scope-unique id. This parameter is required.
     * @param props - user provided props for the construct. This parameter is required.
     */
    public S3ToLambda(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awsconstructs.services.s3lambda.S3ToLambdaProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.Function getLambdaFunction() {
        return software.amazon.jsii.Kernel.get(this, "lambdaFunction", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.lambda.Function.class));
    }

    public @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.s3.Bucket getS3Bucket() {
        return software.amazon.jsii.Kernel.get(this, "s3Bucket", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.s3.Bucket.class));
    }

    public @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.s3.Bucket getS3LoggingBucket() {
        return software.amazon.jsii.Kernel.get(this, "s3LoggingBucket", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.s3.Bucket.class));
    }

    /**
     * A fluent builder for {@link software.amazon.awsconstructs.services.s3lambda.S3ToLambda}.
     */
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awsconstructs.services.s3lambda.S3ToLambda> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope - represents the scope for all the resources. This parameter is required.
         * @param id - this is a a scope-unique id. This parameter is required.
         */
        public static Builder create(final software.amazon.awscdk.core.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.amazon.awscdk.core.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awsconstructs.services.s3lambda.S3ToLambdaProps.Builder props;

        private Builder(final software.amazon.awscdk.core.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awsconstructs.services.s3lambda.S3ToLambdaProps.Builder();
        }

        /**
         * User provided props to override the default props for the S3 Bucket.
         * <p>
         * Default: - Default props are used
         * <p>
         * @return {@code this}
         * @param bucketProps User provided props to override the default props for the S3 Bucket. This parameter is required.
         */
        public Builder bucketProps(final software.amazon.awscdk.services.s3.BucketProps bucketProps) {
            this.props.bucketProps(bucketProps);
            return this;
        }

        /**
         * Existing instance of S3 Bucket object, if this is set then the bucketProps is ignored.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param existingBucketObj Existing instance of S3 Bucket object, if this is set then the bucketProps is ignored. This parameter is required.
         */
        public Builder existingBucketObj(final software.amazon.awscdk.services.s3.Bucket existingBucketObj) {
            this.props.existingBucketObj(existingBucketObj);
            return this;
        }

        /**
         * Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param existingLambdaObj Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored. This parameter is required.
         */
        public Builder existingLambdaObj(final software.amazon.awscdk.services.lambda.Function existingLambdaObj) {
            this.props.existingLambdaObj(existingLambdaObj);
            return this;
        }

        /**
         * User provided props to override the default props for the Lambda function.
         * <p>
         * Default: - Default props are used
         * <p>
         * @return {@code this}
         * @param lambdaFunctionProps User provided props to override the default props for the Lambda function. This parameter is required.
         */
        public Builder lambdaFunctionProps(final software.amazon.awscdk.services.lambda.FunctionProps lambdaFunctionProps) {
            this.props.lambdaFunctionProps(lambdaFunctionProps);
            return this;
        }

        /**
         * Optional user provided props to override the default props.
         * <p>
         * Default: - Default props are used
         * <p>
         * @return {@code this}
         * @param s3EventSourceProps Optional user provided props to override the default props. This parameter is required.
         */
        public Builder s3EventSourceProps(final software.amazon.awscdk.services.lambda.eventsources.S3EventSourceProps s3EventSourceProps) {
            this.props.s3EventSourceProps(s3EventSourceProps);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awsconstructs.services.s3lambda.S3ToLambda}.
         */
        @Override
        public software.amazon.awsconstructs.services.s3lambda.S3ToLambda build() {
            return new software.amazon.awsconstructs.services.s3lambda.S3ToLambda(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}

==> s3lambda-1.122.0-sources.jar: software/amazon/awsconstructs/services/s3lambda/S3ToLambda.java <==
package software.amazon.awsconstructs.services.s3lambda;

@javax.annotation.Generated(value = "jsii-pacmak/1.34.0 (build 9b72778)", date = "2021-09-20T01:04:51.724Z")
@software.amazon.jsii.Jsii(module = software.amazon.awsconstructs.services.s3lambda.$Module.class, fqn = "@aws-solutions-constructs/aws-s3-lambda.S3ToLambda")
public class S3ToLambda extends software.amazon.awscdk.core.Construct {

    protected S3ToLambda(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected S3ToLambda(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope - represents the scope for all the resources. This parameter is required.
     * @param id - this is a a scope-unique id. This parameter is required.
     * @param props - user provided props for the construct. This parameter is required.
     */
    public S3ToLambda(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awsconstructs.services.s3lambda.S3ToLambdaProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.Function getLambdaFunction() {
        return software.amazon.jsii.Kernel.get(this, "lambdaFunction", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.lambda.Function.class));
    }

    public @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.s3.Bucket getS3Bucket() {
        return software.amazon.jsii.Kernel.get(this, "s3Bucket", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.s3.Bucket.class));
    }

    public @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.s3.Bucket getS3LoggingBucket() {
        return software.amazon.jsii.Kernel.get(this, "s3LoggingBucket", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.s3.Bucket.class));
    }

    /**
     * A fluent builder for {@link software.amazon.awsconstructs.services.s3lambda.S3ToLambda}.
     */
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awsconstructs.services.s3lambda.S3ToLambda> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope - represents the scope for all the resources. This parameter is required.
         * @param id - this is a a scope-unique id. This parameter is required.
         */
        public static Builder create(final software.amazon.awscdk.core.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.amazon.awscdk.core.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awsconstructs.services.s3lambda.S3ToLambdaProps.Builder props;

        private Builder(final software.amazon.awscdk.core.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awsconstructs.services.s3lambda.S3ToLambdaProps.Builder();
        }

        /**
         * User provided props to override the default props for the S3 Bucket.
         * <p>
         * Default: - Default props are used
         * <p>
         * @return {@code this}
         * @param bucketProps User provided props to override the default props for the S3 Bucket. This parameter is required.
         */
        public Builder bucketProps(final software.amazon.awscdk.services.s3.BucketProps bucketProps) {
            this.props.bucketProps(bucketProps);
            return this;
        }

        /**
         * Existing instance of S3 Bucket object, providing both this and `bucketProps` will cause an error.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param existingBucketObj Existing instance of S3 Bucket object, providing both this and `bucketProps` will cause an error. This parameter is required.
         */
        public Builder existingBucketObj(final software.amazon.awscdk.services.s3.Bucket existingBucketObj) {
            this.props.existingBucketObj(existingBucketObj);
            return this;
        }

        /**
         * Existing instance of Lambda Function object, providing both this and `lambdaFunctionProps` will cause an error.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param existingLambdaObj Existing instance of Lambda Function object, providing both this and `lambdaFunctionProps` will cause an error. This parameter is required.
         */
        public Builder existingLambdaObj(final software.amazon.awscdk.services.lambda.Function existingLambdaObj) {
            this.props.existingLambdaObj(existingLambdaObj);
            return this;
        }

        /**
         * User provided props to override the default props for the Lambda function.
         * <p>
         * Default: - Default props are used
         * <p>
         * @return {@code this}
         * @param lambdaFunctionProps User provided props to override the default props for the Lambda function. This parameter is required.
         */
        public Builder lambdaFunctionProps(final software.amazon.awscdk.services.lambda.FunctionProps lambdaFunctionProps) {
            this.props.lambdaFunctionProps(lambdaFunctionProps);
            return this;
        }

        /**
         * Optional user provided props to override the default props.
         * <p>
         * Default: - Default props are used
         * <p>
         * @return {@code this}
         * @param s3EventSourceProps Optional user provided props to override the default props. This parameter is required.
         */
        public Builder s3EventSourceProps(final software.amazon.awscdk.services.lambda.eventsources.S3EventSourceProps s3EventSourceProps) {
            this.props.s3EventSourceProps(s3EventSourceProps);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awsconstructs.services.s3lambda.S3ToLambda}.
         */
        @Override
        public software.amazon.awsconstructs.services.s3lambda.S3ToLambda build() {
            return new software.amazon.awsconstructs.services.s3lambda.S3ToLambda(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}
